@@ -4,10 +4,9 @@
  */
 
 export default function (visitable, creatable, roles, popoverSelect) {
-  return {
+  return creatable({
     visit: visitable('/:dc/acls/roles'),
     roles: roles(),
     sort: popoverSelect('[data-test-sort-control]'),
-    ...creatable(),
-  };
+  });
 }
